This patch renames the top half handler and the bottom half handler
of iio_triggered_buffer_setup() in accordance with their usage.
The bottom half has been renamed to reflect the fact that it is a
thread based call, compliant with iio_alloc_pollfunc().
The names of the parameters were swapped, thus creating confusion.

Signed-off-by: Cristina Opriceana <cristina.oprice...@gmail.com>
---
Changes in v2:
        - rename params in iio_triggered_buffer_setup() to h and thread
        - make the commit message reflect the changes
 drivers/iio/industrialio-triggered-buffer.c | 12 ++++++------
 include/linux/iio/triggered_buffer.h        |  4 ++--
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/include/linux/iio/triggered_buffer.h 
b/include/linux/iio/triggered_buffer.h
index c378ebe..f72f70d 100644
--- a/include/linux/iio/triggered_buffer.h
+++ b/include/linux/iio/triggered_buffer.h
@@ -7,8 +7,8 @@ struct iio_dev;
 struct iio_buffer_setup_ops;
 
 int iio_triggered_buffer_setup(struct iio_dev *indio_dev,
-       irqreturn_t (*pollfunc_bh)(int irq, void *p),
-       irqreturn_t (*pollfunc_th)(int irq, void *p),
+       irqreturn_t (*h)(int irq, void *p),
+       irqreturn_t (*thread)(int irq, void *p),
        const struct iio_buffer_setup_ops *setup_ops);
 void iio_triggered_buffer_cleanup(struct iio_dev *indio_dev);
 
diff --git a/drivers/iio/industrialio-triggered-buffer.c 
b/drivers/iio/industrialio-triggered-buffer.c
index 15a5341..4b2858b 100644
--- a/drivers/iio/industrialio-triggered-buffer.c
+++ b/drivers/iio/industrialio-triggered-buffer.c
@@ -24,8 +24,8 @@ static const struct iio_buffer_setup_ops 
iio_triggered_buffer_setup_ops = {
 /**
  * iio_triggered_buffer_setup() - Setup triggered buffer and pollfunc
  * @indio_dev:         IIO device structure
  * @pollfunc_bh:       Function which will be used as pollfunc bottom half
  * @pollfunc_th:       Function which will be used as pollfunc top half
  * @setup_ops:         Buffer setup functions to use for this device.
  *                     If NULL the default setup functions for triggered
  *                     buffers will be used.
@@ -42,8 +42,8 @@ static const struct iio_buffer_setup_ops 
iio_triggered_buffer_setup_ops = {
  * iio_triggered_buffer_cleanup().
  */
 int iio_triggered_buffer_setup(struct iio_dev *indio_dev,
-       irqreturn_t (*pollfunc_bh)(int irq, void *p),
-       irqreturn_t (*pollfunc_th)(int irq, void *p),
+       irqreturn_t (*h)(int irq, void *p),
+       irqreturn_t (*thread)(int irq, void *p),
        const struct iio_buffer_setup_ops *setup_ops)
 {
        struct iio_buffer *buffer;
@@ -57,8 +57,8 @@ int iio_triggered_buffer_setup(struct iio_dev *indio_dev,
 
        iio_device_attach_buffer(indio_dev, buffer);
 
-       indio_dev->pollfunc = iio_alloc_pollfunc(pollfunc_bh,
-                                                pollfunc_th,
+       indio_dev->pollfunc = iio_alloc_pollfunc(h,
+                                                thread,
                                                 IRQF_ONESHOT,
                                                 indio_dev,
                                                 "%s_consumer%d",
@@ -24,8 +24,8 @@ static const struct iio_buffer_setup_ops 
  * iio_triggered_buffer_setup() - Setup triggered buffer and pollfunc
  * @indio_dev:         IIO device structure
- * @pollfunc_bh:       Function which will be used as pollfunc bottom half
- * @pollfunc_th:       Function which will be used as pollfunc top half
+ * @h:                 Function which will be used as pollfunc top half
+ * @thread:            Function which will be used as pollfunc bottom half
  * @setup_ops:         Buffer setup functions to use for this device.
  *                     If NULL the default setup functions for triggered
-- 
1.9.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to